Constructs a list of all file-reading functions based on extension
get_file_reading_functions()Named list where the names are file extensions, and the values are functions that read a file. All functions have ... arguments that can be used to extend the basic function.