R/autowrite.R
autowrite.Rd
Automatically write an object to a file based on extension
autowrite(x, file, ...)
Object to be saved
Full path to save the object to
Other arguments to be passed to the particular saving function
Invisibly passes TRUE if the file saves successfully
get_file_writing_functions() autoread()
get_file_writing_functions()
autoread()